summaryrefslogtreecommitdiff
path: root/sbin
diff options
context:
space:
mode:
authorHenning Brauer <henning@cvs.openbsd.org>2005-02-28 14:04:52 +0000
committerHenning Brauer <henning@cvs.openbsd.org>2005-02-28 14:04:52 +0000
commit97658e2f26b7cacae2b97f1736a8aa8ecf3c758e (patch)
tree189e2c09a67ecf6847d634f5dfc262c9251bacb0 /sbin
parent4d79fe1fed6e1a863c5cb3c5fa9fb9eeb5fdcd25 (diff)
use the linkshar keyword when gtalking about the link sharing service
curve, inspired by PR4127
Diffstat (limited to 'sbin')
-rw-r--r--sbin/pfctl/pfctl_altq.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sbin/pfctl/pfctl_altq.c b/sbin/pfctl/pfctl_altq.c
index 0e08e2918d8..3f5b0875671 100644
--- a/sbin/pfctl/pfctl_altq.c
+++ b/sbin/pfctl/pfctl_altq.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: pfctl_altq.c,v 1.85 2004/05/20 12:18:52 henning Exp $ */
+/* $OpenBSD: pfctl_altq.c,v 1.86 2005/02/28 14:04:51 henning Exp $ */
/*
* Copyright (c) 2002
@@ -709,7 +709,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
* for the real-time service curve, the sum of the service curves
* should not exceed 80% of the interface bandwidth. 20% is reserved
* not to over-commit the actual interface bandwidth.
* for the link-sharing service curve, the sum of the child service
* curve should not exceed the parent service curve.
* for the upper-limit service curve, the assigned bandwidth should
* be smaller than the interface bandwidth, and the upper-limit should
@@ -736,7 +736,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
if (strncmp(altq->parent, pa->parent, PF_QNAME_SIZE) != 0)
continue;
- /* if the class has a link-sharing service curve, add it. */
+ /* if the class has a linkshare service curve, add it. */
if (opts->lssc_m2 != 0 && altq->pq_u.hfsc_opts.lssc_m2 != 0) {
sc.m1 = altq->pq_u.hfsc_opts.lssc_m1;
sc.d = altq->pq_u.hfsc_opts.lssc_d;
@@ -763,7 +763,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
}
}
/* check the link-sharing service curve. */
if (opts->lssc_m2 != 0) {
/* add this queue to the child sum */
sc.m1 = opts->lssc_m1;
@@ -775,7 +775,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
sc.d = parent->pq_u.hfsc_opts.lssc_d;
sc.m2 = parent->pq_u.hfsc_opts.lssc_m2;
if (!is_gsc_under_sc(&lssc, &sc)) {
- warnx("link-sharing sc exceeds parent's sc");
+ warnx("linkshare sc exceeds parent's sc");
goto err_ret;
}
}
@@ -709,7 +709,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
* should not exceed 80% of the interface bandwidth. 20% is reserved
* not to over-commit the actual interface bandwidth.
- * for the link-sharing service curve, the sum of the child service
+ * for the linkshare service curve, the sum of the child service
* curve should not exceed the parent service curve.
* for the upper-limit service curve, the assigned bandwidth should
@@ -763,7 +763,7 @@ eval_pfqueue_hfsc(struct pfctl *pf, struct pf_altq *pa)
}
}
- /* check the link-sharing service curve. */
+ /* check the linkshare service curve. */
if (opts->lssc_m2 != 0) {
/* add this queue to the child sum */